@@ -1,11 +1,11 @@
 #
-# $Id: Metabrik.pm,v 5e7efd36302e 2015/03/07 10:12:52 gomor $
+# $Id: Metabrik.pm,v 1ebb8741c3c2 2015/03/18 06:42:55 gomor $
 #
 package Metabrik;
 use strict;
 use warnings;
 
-our $VERSION = '1.07';
+our $VERSION = '1.08';
 
 use base qw(Class::Gomor::Hash);
 
@@ -30,7 +30,7 @@ sub brik_version {
 
 sub brik_properties {
    return {
-      revision => '$Revision: 5e7efd36302e $',
+      revision => '$Revision: 1ebb8741c3c2 $',
       tags => [ qw() ],
       attributes => {
          debug => [ qw(0|1) ],
@@ -219,6 +219,28 @@ sub _log_verbose {
    return 1;
 }
 
+sub _log_debug {
+   my $self = shift;
+   my ($msg) = @_;
+
+   if (! $self->debug) {
+      return 1;
+   }
+
+   chomp($msg);
+
+   my $class = $self->brik_class;
+
+   if (defined($self->{log})) {
+      return $self->log->debug($msg, $class);
+   }
+   else {
+      print("[D] $class: $msg\n");
+   }
+
+   return 1;
+}
+
 sub brik_check_properties {
    my $self = shift;
    my ($properties, $use_properties) = @_;
@@ -522,13 +544,17 @@ sub brik_check_require_modules {
       }
    }
 
+   my $error = 0;
    for my $require_modules (@require_modules_list) {
       for my $module (keys %$require_modules) {
          eval("require $module;");
          if ($@) {
             chomp($@);
-            return $self->_log_error("brik_check_require_modules: you have to install ".
-               "Module [$module]: $@");
+            $self->_log_error("brik_check_require_modules: you have to install ".
+               "Module [$module]");
+            $self->_log_debug("brik_check_require_modules: $@");
+            $error++;
+            next;
          }
 
          my @imports = @{$require_modules->{$module}};
@@ -536,14 +562,17 @@ sub brik_check_require_modules {
             eval('$module->import(@imports);');
             if ($@) {
             chomp($@);
-               return $self->_log_error("brik_check_require_modules: unable to import ".
-                  "functions [@imports] from Module [$module]: $@");
+               $self->_log_error("brik_check_require_modules: unable to import ".
+                  "functions [@imports] from Module [$module]");
+               $self->_log_debug("brik_check_require_modules: $@");
+               $error++;
+               next;
             }
          }
       }
    }
 
-   return 1;
+   return $error ? 0 : 1;
 }
 
 sub brik_check_require_used {
@@ -570,8 +599,8 @@ sub brik_check_require_used {
 
    my $used = $context->used;
 
+   my $error = 0;
    for my $require_used (@require_used_list) {
-      my $error = 0;
       for my $brik (keys %$require_used) {
          next if $context->is_used($brik);
 
@@ -589,15 +618,12 @@ sub brik_check_require_used {
          else {
             $self->_log_error("brik_check_require_used: you must use Brik [$brik] first");
             $error++;
+            next;
          }
       }
-
-      if ($error) {
-         return;
-      }
    }
 
-   return 1;
+   return $error ? 0 : 1;
 }
 
 sub brik_check_require_binaries {
