@@ -1,5 +1,5 @@
 #
-# $Id: Command.pm,v fb8748327b72 2015/03/08 11:16:55 gomor $
+# $Id: Command.pm,v ed08d3ef999e 2015/03/16 06:40:47 gomor $
 #
 # shell::command Brik
 #
@@ -7,13 +7,13 @@ package Metabrik::Shell::Command;
 use strict;
 use warnings;
 
-our $VERSION = '1.07';
+our $VERSION = '1.08';
 
 use base qw(Metabrik);
 
 sub brik_properties {
    return {
-      revision => '$Revision: fb8748327b72 $',
+      revision => '$Revision: ed08d3ef999e $',
       tags => [ qw(main shell command system) ],
       attributes => {
          as_array => [ qw(0|1) ],
@@ -24,6 +24,9 @@ sub brik_properties {
          system => [ qw(command) ],
          capture => [ qw(command) ],
       },
+      require_modules => {
+         'IPC::Run3' => [ ],
+      },
    };
 }
 
@@ -77,7 +80,9 @@ sub system {
    $command = join(' ', @toks);
    my $r = CORE::system($command);
 
-   return defined($r) ? 1 : 0;
+   # system() returns program exit code in case of success
+   # So we return $? in case of success, and 0 otherwise
+   return defined($r) ? $? : 0;
 }
 
 sub capture {
@@ -117,11 +122,30 @@ sub capture {
 
    $command = join(' ', @toks);
 
-   my $out = $self->capture_stderr ? `$command 2>&1` : `$command`;
+   my $out;
+   my $err;
+   eval {
+      IPC::Run3::run3(\@toks, undef, \$out, \$err);
+   };
+   # Error in executing run3()
+   if ($@) {
+      chomp($@);
+      return $self->log->error("capture: unable to execute command [$command]: $@");
+   }
+   # Error in command execution
+   elsif ($?) {
+      chomp($err);
+      return $self->log->error("capture: command execution failed [$command]: $err");
+   }
+
    $out ||= 'undef';
+   $err ||= 'undef';
    chomp($out);
-   if ($?) {
-      return $self->log->error("capture: exec failed [$out]");
+   chomp($err);
+
+   # If we also wanted stderr, we put it at the end of output
+   if ($self->capture_stderr) {
+      $out .= "\n\nSTDERR:\n$err";
    }
 
    # as_matrix has precedence over as_array (because as_array is the default)
